@@ -52,6 +52,7 @@ var _ = Describe("LogForwarding", func() {
 					Name: "instance",
 				},
 				Spec: logforward.ForwardingSpec{
+					DisableDefaultForwarding: true,
 					Outputs: []logforward.OutputSpec{
 						logforward.OutputSpec{
 							Name: elasticsearch.Name,
@@ -95,6 +96,7 @@ var _ = Describe("LogForwarding", func() {
 
 		AfterEach(func() {
 			e2e.Cleanup()
+			e2e.WaitForCleanupCompletion([]string{"fluentd", "elasticsearch"})
 		})
 
 		It("should send logs to the forward.Output logstore", func() {
